/*
Template Name: Velzon - Admin & Dashboard Template
Author: Themesbrand
Version: 4.0.0
Website: https://Themesbrand.com/
Contact: Themesbrand@gmail.com
File: Icons Css File
*/

// Icons Scss
@import "plugins/icons/materialdesignicons";
@import "plugins/icons/boxicons";
@import "plugins/icons/line-awesome";
@import "plugins/icons/remixicon";