main > .container {
    padding: 70px 15px 20px;
}

.footer {
    background-color: #f5f5f5;
    font-size: .9em;
    height: 60px;
}

.footer > .container {
    padding-right: 15px;
    padding-left: 15px;
}

.not-set {
    color: #c55;
    font-style: italic;
}

/* add sorting icons to gridview sort links */
a.asc:after, a.desc:after {
    content: '';
    left: 3px;
    display: inline-block;
    width: 0;
    height: 0;
    border: solid 5px transparent;
    margin: 4px 4px 2px 4px;
    background: transparent;
}

a.asc:after {
    border-bottom: solid 7px #212529;
    border-top-width: 0;
}

a.desc:after {
    border-top: solid 7px #212529;
    border-bottom-width: 0;
}

.grid-view th,
.grid-view td:last-child {
    white-space: nowrap;
}

.grid-view .filters input,
.grid-view .filters select {
    min-width: 50px;
}

.hint-block {
    display: block;
    margin-top: 5px;
    color: #999;
}

.error-summary {
    color: #a94442;
    background: #fdf7f7;
    border-left: 3px solid #eed3d7;
    padding: 10px 20px;
    margin: 0 0 15px 0;
}

/* align the logout "link" (button in form) of the navbar */
.nav li > form > button.logout {
    padding-top: 7px;
    color: rgba(255, 255, 255, 0.5);
}

@media(max-width:767px) {
    .nav li > form > button.logout {
        display:block;
        text-align: left;
        width: 100%;
        padding: 10px 0;
    }
}

.nav > li > form > button.logout:focus,
.nav > li > form > button.logout:hover {
    text-decoration: none;
    color: rgba(255, 255, 255, 0.75);
}

.nav > li > form > button.logout:focus {
    outline: none;
}

.pagination-next.disabled, .pagination-prev.disabled {
    color: var(--vz-secondary-color);
    cursor: default;
}
.pagination-next, .pagination-prev {
    color: var(--vz-primary);
    font-weight: var(--vz-font-weight-medium);
    padding: .375rem .75rem;
    background-color: var(--vz-secondary-bg);
    border: var(--vz-border-width) solid var(--vz-border-color);
    border-radius: .25rem;
}

/* Override the checked color for radio buttons */
.custom-radio .radio-inline input[type="radio"]:checked + label {
    color: inherit; /* or specify another color */
}

/* Override the Bootstrap default color for radio inputs */
.custom-radio .radio-inline input[type="radio"]:checked {
    background-color: transparent; /* or set to your preferred color */
    border-color: inherit; /* Match border color to default */
    box-shadow: none; /* Remove the default shadow */
}