/*
 * noVNC black CSS
 * Copyright (C) 2012 Joel Martin
 * Copyright (C) 2013 Samuel Mannehed for Cendio AB
 * noVNC is licensed under the MPL 2.0 (see LICENSE.txt)
 * This file is licensed under the 2-Clause BSD license (see LICENSE.txt).
 */

.noVNC_panel {
    border: 0px;
    background:#4c4c4c;;
    color:#fff;
}

#noVNC_control_bar, #noVNC_control_bar_handle, .noVNC_panel .noVNC_heading {
    background: #4c4c4c;
}

.noVNC_button.noVNC_selected {
    background: #3892d4;
}

#pve_commands > input[type=button] {
    width: 100%;
}

#noVNC_canvas:focus {
    outline: none;
}

#noVNC_transition {
    z-index: 0;
}

#noVNC_connect_button {
    display: none;
}

:root:not(.noVNC_touch) .noVNC_button.noVNC_selected:hover {
  border-color: rgba(0, 0, 0, 0.4);
  background: #5BA8DF;
}

.noVNC_button.pve_hidden {
  display: none !important;
}

/* start button */
#pve_start_dlg {
  transition: 0.2s ease-in-out;
  transform: scale(0, 0);
  visibility: hidden;
  opacity: 0;
}

#pve_start_dlg.noVNC_open {
  transform: scale(1, 1);
  visibility: visible;
  opacity: 1;
}

#pve_start_info {
  color: white;
  text-align: center;
  font-size: 20px;
  padding: 6px;
}

#pve_start_button {
  cursor: pointer;
  padding: 6px;
  color: white;
  background:#4c4c4c;;
  border-radius: 8px;
  text-align: center;
  font-size: 20px;
  box-shadow: 4px 4px 0px rgba(0, 0, 0, 0.5);
}

#pve_start_button div {
  margin: 2px;
  padding: 5px 30px;
  border: 1px solid #2f2f2f;
  border-bottom-width: 2px;
  border-radius: 5px;
  background:#4c4c4c;;

  /* This avoids it jumping around when :active */
  vertical-align: middle;
}

#pve_start_button div:active {
  border-bottom-width: 1px;
  margin-top: 3px;
}

:root:not(.noVNC_touch) #pve_start_button div:hover {
  background: rgba(255, 255, 255, 0.2);
}

#pve_start_button img {
  vertical-align: bottom;
  padding: 0 5px 2px 0;
}
