main>.container {
    padding: 70px 15px 20px;
}

.footer {
    background-color: #f5f5f5;
    font-size: .9em;
    height: 60px;
}

.footer>.container {
    padding-right: 15px;
    padding-left: 15px;
}

.not-set {
    color: #c55;
    font-style: italic;
}

/* add sorting icons to gridview sort links */
a.asc:after,
a.desc:after {
    content: '';
    left: 3px;
    display: inline-block;
    width: 0;
    height: 0;
    border: solid 5px transparent;
    margin: 4px 4px 2px 4px;
    background: transparent;
}

a.asc:after {
    border-bottom: solid 7px #212529;
    border-top-width: 0;
}

a.desc:after {
    border-top: solid 7px #212529;
    border-bottom-width: 0;
}

[data-bs-theme="dark"] a.asc:after {
    border-bottom-color: #dee2e6;
}

[data-bs-theme="dark"] a.desc:after {
    border-top-color: #dee2e6;
}

.grid-view th {
    white-space: nowrap;
}

.hint-block {
    display: block;
    margin-top: 5px;
    color: #999;
}

.error-summary {
    color: #a94442;
    background: #fdf7f7;
    border-left: 3px solid #eed3d7;
    padding: 10px 20px;
    margin: 0 0 15px 0;
}

/* align the logout "link" (button in form) of the navbar */
.nav li>form>button.logout {
    padding-top: 7px;
    color: rgba(255, 255, 255, 0.5);
}

@media(max-width:767px) {
    .nav li>form>button.logout {
        display: block;
        text-align: left;
        width: 100%;
        padding: 10px 0;
    }
}

.nav>li>form>button.logout:focus,
.nav>li>form>button.logout:hover {
    text-decoration: none;
    color: rgba(255, 255, 255, 0.75);
}

.nav>li>form>button.logout:focus {
    outline: none;
}

div.main-content>div>div>div.row>div>div>div>ol>nav {
    height: 19px;
}

.has-error .help-block {
    color: red;
}

.pagination {
    /* float: right!important;  */
}

/* .pagination li {
    margin: 0 10px; 
} */

.pagination li {
    display: inline-block;
    margin-right: 5px;
    border: 1px solid #ccc;
    border-radius: 5px;
    margin-top: 10px;
}

.pagination li a,
.pagination li span {
    display: block;
    padding: 5px 12px;
    text-decoration: none;
    color: inherit;
}

.pagination li.active {
    background-color: #405189;
    /* Active item background color */
    color: #fff !important;
    /* Active item text color */
    border-color: #405189;
    /* Active item border color */
}

.pagination li.active a {
    color: #fff !important;
}

.pagination li.disabled {
    opacity: 0.5;
    pointer-events: none;
    border-color: #e9ecef;
}

.pagination li.disabled a,
.pagination li.disabled span {
    color: #adb5bd;
}

.modal-btn {
    cursor: pointer;
}

.spinner-grow {
    margin-left: 1em;
}

.vm-grid i.las {
    position: relative;
    top: 3px;
}

i.las {
    font-size: 1.5em;
}

/**Added because there is something breaking with the dropdown button */
.dropdown-toggle::after {
    content: "" !important;
}
/* Adjust the z-index of the Select2 dropdown */
.select2-container--default .select2-dropdown, .select2-container, .select2-container--krajee-bs3 {
    z-index: 1026;
    /* Default z-index for Select2 outside modals */
}
.select2-below-modal-or-dropdown + .select2-container--default .select2-dropdown,
.select2-below-modal-or-dropdown + .select2-container,
.select2-below-modal-or-dropdown + .select2-container--krajee-bs3 {
    z-index: 1000 !important;
}

/* Select2 dropdown with higher z-index for modals (Bootstrap 5 modal is at 1055) */
.select2-container--open{
    z-index: 1056 !important;
}

.select2-container--default .select2-selection--multiple .select2-selection__choice__display {
    color: #333;
}

/* Dark mode: selected choice text in multi-select */
[data-bs-theme="dark"] .select2-container--default .select2-selection--multiple .select2-selection__choice__display,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-selection--multiple .select2-selection__choice__display {
    color: #dee2e6 !important;
}

[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-selection--multiple .select2-selection__choice {
    color: #dee2e6 !important;
    background: #343a40 !important;
}

.storage-container {
    margin-bottom: 10px !important;
}
.select2-container .select2-selection--single .select2-selection__rendered {
    line-height: 24px!important;
}

/* Dark mode support for Select2 */
[data-bs-theme="dark"] .select2-container--default .select2-selection--single,
[data-bs-theme="dark"] .select2-container--default .select2-selection--multiple,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-selection--single,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-selection--multiple,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-selection--single,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-selection--multiple,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-selection--single,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-selection--multiple {
    background-color: #212529 !important;
    border-color: #495057 !important;
}

[data-bs-theme="dark"] .select2-container--default .select2-selection--single .select2-selection__rendered,
[data-bs-theme="dark"] .select2-container--default .select2-selection--multiple .select2-selection__rendered,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-selection--single .select2-selection__rendered,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-selection--multiple .select2-selection__rendered,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-selection--single .select2-selection__rendered,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-selection--multiple .select2-selection__rendered,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-selection--single .select2-selection__rendered,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-selection--multiple .select2-selection__rendered {
    color: #dee2e6 !important;
}

[data-bs-theme="dark"] .select2-container--default .select2-selection--single .select2-selection__placeholder,
[data-bs-theme="dark"] .select2-container--default .select2-selection--multiple .select2-selection__placeholder,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-selection--single .select2-selection__placeholder,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-selection--multiple .select2-selection__placeholder,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-selection--single .select2-selection__placeholder,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-selection--multiple .select2-selection__placeholder,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-selection--single .select2-selection__placeholder,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-selection--multiple .select2-selection__placeholder {
    color: #6c757d !important;
}

[data-bs-theme="dark"] .select2-dropdown,
[data-bs-theme="dark"] .select2-dropdown.select2-dropdown--below,
[data-bs-theme="dark"] .select2-dropdown.select2-dropdown--above {
    background-color: #212529 !important;
    border-color: #495057 !important;
}

[data-bs-theme="dark"] .select2-container--default .select2-results__option,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-results__option,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-results__option,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-results__option {
    background-color: #212529 !important;
    color: #dee2e6 !important;
}

[data-bs-theme="dark"] .select2-container--default .select2-results__option--highlighted[aria-selected],
[data-bs-theme="dark"] .select2-container--default .select2-results__option--highlighted.select2-results__option--selectable,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-results__option--highlighted[aria-selected],
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-results__option--highlighted.select2-results__option--selectable,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-results__option--highlighted[aria-selected],
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-results__option--highlighted.select2-results__option--selectable,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-results__option--highlighted[aria-selected],
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-results__option--highlighted.select2-results__option--selectable {
    background-color: #0d6efd !important;
    color: white !important;
}

[data-bs-theme="dark"] .select2-container--default .select2-results__option[aria-selected="true"],
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-results__option[aria-selected="true"],
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-results__option[aria-selected="true"],
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-results__option[aria-selected="true"] {
    background-color: #343a40 !important;
    color: #dee2e6 !important;
}

[data-bs-theme="dark"] .select2-container--default .select2-search--dropdown .select2-search__field,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-search--dropdown .select2-search__field,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-search--dropdown .select2-search__field,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-search--dropdown .select2-search__field {
    background-color: #343a40 !important;
    border-color: #495057 !important;
    color: #dee2e6 !important;
}

[data-bs-theme="dark"] .select2-container--default .select2-selection--multiple .select2-selection__choice,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-selection--multiple .select2-selection__choice,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-selection--multiple .select2-selection__choice,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-selection--multiple .select2-selection__choice {
    background-color: #343a40 !important;
    border-color: #495057 !important;
    color: #dee2e6 !important;
}

[data-bs-theme="dark"] .select2-container--default .select2-selection--multiple .select2-selection__choice__remove,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-selection--multiple .select2-selection__choice__remove,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-selection--multiple .select2-selection__choice__remove,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-selection--multiple .select2-selection__choice__remove {
    color: #dee2e6 !important;
}

[data-bs-theme="dark"] .select2-container--default .select2-selection--single .select2-selection__arrow b,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-selection--single .select2-selection__arrow b,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-selection--single .select2-selection__arrow b,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-selection--single .select2-selection__arrow b {
    border-color: #dee2e6 transparent transparent transparent !important;
}

[data-bs-theme="dark"] .select2-container--default.select2-container--open .select2-selection--single .select2-selection__arrow b,
[data-bs-theme="dark"] .select2-container--krajee-bs3.select2-container--open .select2-selection--single .select2-selection__arrow b,
[data-bs-theme="dark"] .select2-container--krajee-bs4.select2-container--open .select2-selection--single .select2-selection__arrow b,
[data-bs-theme="dark"] .select2-container--krajee-bs5.select2-container--open .select2-selection--single .select2-selection__arrow b {
    border-color: transparent transparent #dee2e6 transparent !important;
}

/* Fix for results container */
[data-bs-theme="dark"] .select2-results,
[data-bs-theme="dark"] .select2-results__options {
    background-color: #212529 !important;
}

/* Remove blue shadow/outline on Select2 focus */
.select2-container--default .select2-selection--single:focus,
.select2-container--default .select2-selection--multiple:focus,
.select2-container--krajee-bs3 .select2-selection--single:focus,
.select2-container--krajee-bs3 .select2-selection--multiple:focus,
.select2-container--krajee-bs4 .select2-selection--single:focus,
.select2-container--krajee-bs4 .select2-selection--multiple:focus,
.select2-container--krajee-bs5 .select2-selection--single:focus,
.select2-container--krajee-bs5 .select2-selection--multiple:focus,
.select2-container--default.select2-container--focus .select2-selection--single,
.select2-container--default.select2-container--focus .select2-selection--multiple,
.select2-container--krajee-bs3.select2-container--focus .select2-selection--single,
.select2-container--krajee-bs3.select2-container--focus .select2-selection--multiple,
.select2-container--krajee-bs4.select2-container--focus .select2-selection--single,
.select2-container--krajee-bs4.select2-container--focus .select2-selection--multiple,
.select2-container--krajee-bs5.select2-container--focus .select2-selection--single,
.select2-container--krajee-bs5.select2-container--focus .select2-selection--multiple {
    outline: none !important;
    box-shadow: none !important;
    border-color: #495057 !important;
}

/* Also remove shadow in dark mode */
[data-bs-theme="dark"] .select2-container--default .select2-selection--single:focus,
[data-bs-theme="dark"] .select2-container--default .select2-selection--multiple:focus,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-selection--single:focus,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-selection--multiple:focus,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-selection--single:focus,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-selection--multiple:focus,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-selection--single:focus,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-selection--multiple:focus,
[data-bs-theme="dark"] .select2-container--default.select2-container--focus .select2-selection--single,
[data-bs-theme="dark"] .select2-container--default.select2-container--focus .select2-selection--multiple,
[data-bs-theme="dark"] .select2-container--krajee-bs3.select2-container--focus .select2-selection--single,
[data-bs-theme="dark"] .select2-container--krajee-bs3.select2-container--focus .select2-selection--multiple,
[data-bs-theme="dark"] .select2-container--krajee-bs4.select2-container--focus .select2-selection--single,
[data-bs-theme="dark"] .select2-container--krajee-bs4.select2-container--focus .select2-selection--multiple,
[data-bs-theme="dark"] .select2-container--krajee-bs5.select2-container--focus .select2-selection--single,
[data-bs-theme="dark"] .select2-container--krajee-bs5.select2-container--focus .select2-selection--multiple {
    outline: none !important;
    box-shadow: none !important;
    border-color: #495057 !important;
}

/* Remove shadow from dropdown panel */
.select2-dropdown,
.select2-dropdown.select2-dropdown--below,
.select2-dropdown.select2-dropdown--above {
    box-shadow: none !important;
    border: 1px solid #dee2e6 !important;
}

[data-bs-theme="dark"] .select2-dropdown,
[data-bs-theme="dark"] .select2-dropdown.select2-dropdown--below,
[data-bs-theme="dark"] .select2-dropdown.select2-dropdown--above {
    box-shadow: none !important;
    border: 1px solid #495057 !important;
}

/* Remove any focus/active shadows from options */
.select2-container--default .select2-results__option:focus,
.select2-container--default .select2-results__option:active,
.select2-container--krajee-bs3 .select2-results__option:focus,
.select2-container--krajee-bs3 .select2-results__option:active,
.select2-container--krajee-bs4 .select2-results__option:focus,
.select2-container--krajee-bs4 .select2-results__option:active,
.select2-container--krajee-bs5 .select2-results__option:focus,
.select2-container--krajee-bs5 .select2-results__option:active {
    outline: none !important;
    box-shadow: none !important;
}

[data-bs-theme="dark"] .select2-container--default .select2-results__option:focus,
[data-bs-theme="dark"] .select2-container--default .select2-results__option:active,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-results__option:focus,
[data-bs-theme="dark"] .select2-container--krajee-bs3 .select2-results__option:active,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-results__option:focus,
[data-bs-theme="dark"] .select2-container--krajee-bs4 .select2-results__option:active,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-results__option:focus,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-results__option:active {
    outline: none !important;
    box-shadow: none !important;
}

/* Dark mode support for Select2 clear button */
[data-bs-theme="dark"] .select2-selection__clear {
    color: #dee2e6 !important;
}

[data-bs-theme="dark"] .select2-selection__clear:hover {
    color: #ffffff !important;
}

/* Dark mode support for inline search field in multi-select */
[data-bs-theme="dark"] .select2-container--default .select2-selection--multiple .select2-search__field,
[data-bs-theme="dark"] .select2-container--krajee-bs5 .select2-selection--multiple .select2-search__field {
    color: #dee2e6 !important;
}

/* Dark mode support for custom nav active links */
[data-bs-theme="dark"] .nav-custom.nav-custom-light .nav-item .nav-link.active {
    color: white !important;
}
