.multi-wrapper .non-selected-wrapper .item.selected {
    display: none;
}

.os-type-icon {
    font-size: 45px;
}

.form-group.custom-checkbox {
    cursor: pointer;
}

.custom-checkbox.selected {
    --vz-border-opacity: 1;
    border-color: rgba(var(--vz-primary-rgb), var(--vz-border-opacity)) !important;
}

.wizard-nav-link {
    pointer-events: none;
    /* Prevent user interaction */
}

.wizard-nav-link.disabled {
    opacity: 0.5;
    cursor: not-allowed;
    position: relative;
}

.wizard-nav-link.disabled::after {
    content: "This step is unavailable";
    position: absolute;
    background: #ffc107;
    /* Warning color */
    color: #000;
    padding: 5px;
    font-size: 12px;
    border-radius: 4px;
    white-space: nowrap;
    top: 100%;
    left: 50%;
    transform: translateX(-50%);
    opacity: 0;
    transition: opacity 0.2s;
    pointer-events: none;
}

.wizard-nav-link.disabled:hover::after {
    opacity: 1;
}

html[data-bs-theme="dark"] .card-radio .form-check-input:checked+.form-check-label{
    border-color: #9fafe4 !important;
}

html[data-bs-theme="dark"] .text-primary {
    color: #9fafe4 !important;
}

.row-selected {
    cursor: pointer;
    background-color: rgb(64 81 137) !important;
    color: white;
}

.selected-row {
    background-color: rgb(64 81 137) !important;
    color: white;
}

/* Confirmation step styling */
.virtual-machine-list-container .list-group-item {
    border: 1px solid #dee2e6;
    margin-bottom: 0.5rem;
}

.virtual-machine-list-container .badge-container {
    display: flex;
    gap: 0.5rem;
    align-items: center;
    flex-wrap: wrap;
}

.company-container {
    margin-bottom: 1.5rem;
}

.company-container h5 {
    margin-bottom: 0.5rem;
}