/*
To change this license header, choose License Headers in Project Properties.
To change this template file, choose Tools | Templates
and open the template in the editor.
*/
/* 
    Created on : Jul 16, 2014, 8:10:29 AM
    Author     : mdmunirdeb
*/

#manager-menu .pull-right {
    float: right;
}
